@@ -29,7 +29,7 @@
 #include <alljoyn/notification/NotificationText.h>
 #include <alljoyn/controlpanel/ControlPanelService.h>
 #include <alljoyn/controlpanel/ControlPanelControllee.h>
-#include <SrpKeyXListener.h>
+#include <alljoyn/AuthListener.h>
 #include <CommonSampleUtil.h>
 #include <ControlPanelGenerated.h>
 #include <alljoyn/services_common/LogModulesNames.h>
@@ -49,7 +49,7 @@ CommonBusListener* controlpanelBusListener = 0;
 BusAttachment* bus = 0;
 ControlPanelService* controlPanelService = 0;
 ControlPanelControllee* controlPanelControllee = 0;
-SrpKeyXListener* srpKeyXListener = 0;
+DefaultECDHEAuthListener* authListener = 0;
 
 NotificationService* prodService = 0;
 NotificationSender* sender = 0;
@@ -104,9 +104,9 @@ void cleanup()
         delete controlPanelService;
         controlPanelService = NULL;
     }
-    if (srpKeyXListener) {
-        delete srpKeyXListener;
-        srpKeyXListener = NULL;
+    if (authListener) {
+        delete authListener;
+        authListener = NULL;
     }
     if (bus) {
         delete bus;
@@ -137,12 +137,14 @@ start:
     // Initialize Service object and Sender Object
     prodService = NotificationService::getInstance();
 
-    srpKeyXListener = new SrpKeyXListener();
+    authListener = new DefaultECDHEAuthListener();
+    const char *password = "000000";
+    authListener->SetPassword((const uint8_t*)password, strlen(password));
 
     /* Connect to the daemon */
     uint16_t retry = 0;
     do {
-        bus = CommonSampleUtil::prepareBusAttachment(srpKeyXListener);
+        bus = CommonSampleUtil::prepareBusAttachment(authListener);
         if (bus == NULL) {
             std::cout << "Could not initialize BusAttachment. Retrying" << std::endl;
 #ifdef _WIN32
