@@ -20,18 +20,26 @@
 #import "AJCPSControlPanelController.h"
 #import "AJCPSContainer.h"
 #import "AJCPSControllerUpdateEvents.h"
-#import "AJCPSCPSButtonCell.h"
-#import "AJCPSCPSGeneralCell.h"
+#import "AJCPSButtonCell.h"
+#import "AJCPSGeneralCell.h"
+#import "AJCPSLabelCell.h"
+#import "AJCPSPickerCell.h"
+#import "AJCPSActionDialogCell.h"
 
 const float GENERAL_CELL_HEIGHT = 115.00;
 const float BUTTON_CELL_HEIGHT = 65.00;
+const float LABEL_CELL_HEIGHT = 55.00;
+const float PICKER_CELL_HEIGHT = 75.00;
+
 static NSString * const CLIENTDEFAULTLANG=@"";
 static NSString * const CPS_BUTTON_CELL = @"CPSButtonCell";
 static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
+static NSString * const CPS_LABEL_CELL = @"CPSLabelCell";
+static NSString * const CPS_PICKER_CELL = @"CPSPickerCell";
+static NSString * const CPS_ACTION_DIALOG_CELL = @"CPSActionDialogCell";
 
-
-@interface GetControlPanelViewController () <ControllerUpdateEvents,UIAlertViewDelegate>
-@property (strong, nonatomic) ControllerModel *controllerModel;
+@interface AJCPSGetControlPanelViewController () <ControllerUpdateEvents,UIAlertViewDelegate>
+@property (strong, nonatomic) AJCPSControllerModel *controllerModel;
 @property (strong, nonatomic) AJCPSControlPanelService *controlPanelService;
 @property (strong, nonatomic) AJCPSControlPanelController *controlPanelController;
 @property (strong, nonatomic) AJCPSControlPanelDevice *controlPanelDevice;
@@ -50,11 +58,12 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
 @property (strong, nonatomic) AJCPSNotificationAction* notificationAction;
 
 @property (strong, atomic) UIAlertView *loadingAV;
+@property (strong, atomic) UIAlertController *loadingAC;
 
 @end
 
 
-@implementation GetControlPanelViewController
+@implementation AJCPSGetControlPanelViewController
 
 - (id)initWithNotificationSenderBusName:(NSString*) senderBusName cpsObjectPath:(NSString*) cpsObjectPath bus:(AJNBusAttachment*) bus
 {
@@ -84,7 +93,7 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
     
     self.navigationItem.hidesBackButton = YES;
     [self showLoadingAlert:@"Loading..."];
-
+    
     // Add language button
     if (self.isAnnouncementMode) {
         [self addLanguageButton];
@@ -96,10 +105,12 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
         self.tableView = [[UITableView alloc] initWithFrame:tableViewFrame style:UITableViewStylePlain];
         self.tableView.delegate = self;
         self.tableView.dataSource = self;
-        
-        // Add two cells to UITableView :
-        [self.tableView registerClass:[CPSButtonCell class] forCellReuseIdentifier:CPS_BUTTON_CELL];
-        [self.tableView registerClass:[CPSGeneralCell class] forCellReuseIdentifier:CPS_GENERAL_CELL];
+    
+        [self.tableView registerClass:[AJCPSButtonCell class] forCellReuseIdentifier:CPS_BUTTON_CELL];
+        [self.tableView registerClass:[AJCPSGeneralCell class] forCellReuseIdentifier:CPS_GENERAL_CELL];
+        [self.tableView registerClass:[AJCPSLabelCell class] forCellReuseIdentifier:CPS_LABEL_CELL];
+        [self.tableView registerClass:[AJCPSPickerCell class] forCellReuseIdentifier:CPS_PICKER_CELL];
+        [self.tableView registerClass:[AJCPSActionDialogCell class] forCellReuseIdentifier:CPS_ACTION_DIALOG_CELL];
         
         [self.view addSubview:self.tableView];
     
@@ -108,7 +119,6 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
         if (ER_OK != status) {
             NSLog(@"Failed to start control panel");
             [[[UIAlertView alloc] initWithTitle:@"Error" message:@"Failed to start control panel." delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil] show];
-            
             [self loadEnded];
         }
     }
@@ -137,7 +147,7 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
         }
     }
     
-    self.controllerModel = [[ControllerModel alloc] init];
+    self.controllerModel = [[AJCPSControllerModel alloc] init];
     if (!self.controllerModel) {
         NSLog(@"Could not initialize controller model.");
         return ER_FAIL;
@@ -373,7 +383,7 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
             for (NSNumber *hint  in hints) {
                 if(hint.shortValue == AJCPS_ACTIONBUTTON) {
                     
-                    CPSButtonCell *cell = (CPSButtonCell *)[tableView dequeueReusableCellWithIdentifier:CPS_BUTTON_CELL forIndexPath:indexPath];
+                    AJCPSButtonCell *cell = (AJCPSButtonCell *)[tableView dequeueReusableCellWithIdentifier:CPS_BUTTON_CELL forIndexPath:indexPath];
                     
                     cell.actionWidget = (AJCPSAction *)widget;
                     return cell;
@@ -381,18 +391,40 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
             }
             
             break;
+        }   
+        case AJCPS_LABEL:
+        {   
+             AJCPSLabelCell *cell = (AJCPSLabelCell *)[tableView dequeueReusableCellWithIdentifier:CPS_LABEL_CELL forIndexPath:indexPath];
+             cell.widget = widget;
+             cell.selectionStyle = UITableViewCellSelectionStyleNone;
+             return cell;
+        }
+        case AJCPS_PROPERTY:
+        {
+            NSArray *hints = [widget getHints];
+            for (NSNumber *hint  in hints) {
+                if(hint.shortValue == AJCPS_SPINNER) {
+                    AJCPSPickerCell *cell = (AJCPSPickerCell *)[tableView dequeueReusableCellWithIdentifier:CPS_PICKER_CELL forIndexPath:indexPath];
+                    cell.widget = widget;
+                    cell.selectionStyle = UITableViewCellSelectionStyleNone;
+                    return cell;
+                }
+            }
+            
+            break;
+        }
+        case AJCPS_ACTION_WITH_DIALOG:
+        {
+            AJCPSActionDialogCell *cell = (AJCPSActionDialogCell *)[tableView dequeueReusableCellWithIdentifier:CPS_ACTION_DIALOG_CELL forIndexPath:indexPath];
+            cell.viewController = self;
+            cell.actionDialogWidget = (AJCPSActionWithDialog *)widget;
+            return cell;
         }
     }
     
-    CPSGeneralCell *cell;
-    cell = (CPSGeneralCell *)[tableView dequeueReusableCellWithIdentifier:CPS_GENERAL_CELL forIndexPath:indexPath];
-    
+    AJCPSGeneralCell *cell;
+    cell = (AJCPSGeneralCell *)[tableView dequeueReusableCellWithIdentifier:CPS_GENERAL_CELL forIndexPath:indexPath];
     cell.widget = widget;
-    
-    
-    
-    // Configure the cell...
-    
     cell.selectionStyle = UITableViewCellSelectionStyleNone;
     
     return cell;
@@ -411,8 +443,15 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
     
     switch ([widget getWidgetType]) {
         case AJCPS_ACTION:
+        case AJCPS_ACTION_WITH_DIALOG:
             return BUTTON_CELL_HEIGHT;
             break;
+        case AJCPS_LABEL:
+            return LABEL_CELL_HEIGHT;
+            break;
+        case AJCPS_PROPERTY:
+            return PICKER_CELL_HEIGHT;
+            break;
     }
     
     return GENERAL_CELL_HEIGHT;
@@ -427,7 +466,7 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
     AJCPSWidget *widget = [self.controllerModel widgetsContainer][indexPath.row];
     
     if ([widget getWidgetType] == AJCPS_CONTAINER) {
-        GetControlPanelViewController *viewController = [[GetControlPanelViewController alloc] init];
+        AJCPSGetControlPanelViewController *viewController = [[AJCPSGetControlPanelViewController alloc] init];
         
         // prepare the view we load to show the child container widgets
        
@@ -447,17 +486,55 @@ static NSString * const CPS_GENERAL_CELL = @"CPSGeneralCell";
 
 -(void)showLoadingAlert:(NSString *)message
 {
-    self.loadingAV = [[UIAlertView alloc] initWithTitle:@"Please wait" message:message delegate:nil cancelButtonTitle:nil otherButtonTitles:nil];
-    UIActivityIndicatorView *activityIV = [[UIActivityIndicatorView alloc] initWithFrame:CGRectMake(0, 0, 80, 40)];
-    activityIV.activityIndicatorViewStyle = UIActivityIndicatorViewStyleGray;
-    [activityIV startAnimating];
-    [self.loadingAV setValue:activityIV forKey:@"accessoryView"];
-    [self.loadingAV show];
+    if ([UIAlertController class]) {
+        self.loadingAC = [UIAlertController alertControllerWithTitle:nil
+                                                             message:[NSString stringWithFormat:@"%@\n\n", message]
+                                                      preferredStyle:UIAlertControllerStyleAlert];
+        UIActivityIndicatorView *activityIV = [[UIActivityIndicatorView alloc] initWithFrame:self.loadingAC.view.bounds];
+        [activityIV setTranslatesAutoresizingMaskIntoConstraints:NO];
+        activityIV.activityIndicatorViewStyle = UIActivityIndicatorViewStyleGray;
+        [self.loadingAC.view addSubview:activityIV];
+        [self.loadingAC.view addConstraint:[NSLayoutConstraint constraintWithItem:activityIV
+                                                                        attribute:NSLayoutAttributeCenterX
+                                                                        relatedBy:NSLayoutRelationEqual
+                                                                           toItem:self.loadingAC.view
+                                                                        attribute:NSLayoutAttributeCenterX
+                                                                       multiplier:1
+                                                                         constant:0]];
+        [self.loadingAC.view addConstraint:[NSLayoutConstraint constraintWithItem:activityIV
+                                                                        attribute:NSLayoutAttributeCenterY
+                                                                        relatedBy:NSLayoutRelationEqual
+                                                                           toItem:self.loadingAC.view
+                                                                        attribute:NSLayoutAttributeCenterY
+                                                                       multiplier:1
+                                                                         constant:0]];
+        [activityIV startAnimating];
+        [self presentViewController:self.loadingAC animated:NO completion:nil];
+    }
+    else {
+        self.loadingAV = [[UIAlertView alloc] initWithTitle:@"Please wait"
+                                                    message:message
+                                                   delegate:nil
+                                          cancelButtonTitle:nil
+                                          otherButtonTitles:nil];
+        UIActivityIndicatorView *activityIV = [[UIActivityIndicatorView alloc] initWithFrame:CGRectMake(0, 0, 80, 40)];
+        activityIV.activityIndicatorViewStyle = UIActivityIndicatorViewStyleGray;
+        [activityIV startAnimating];
+        [self.loadingAV setValue:activityIV forKey:@"accessoryView"];
+        [self.loadingAV show];
+    }
+    NSLog(@"Showing loading alert");
 }
 
 -(void)dismissLoadingAlert
 {
-    [self.loadingAV dismissWithClickedButtonIndex:0 animated:YES];
+    if ([UIAlertController class]) {
+        [self.loadingAC dismissViewControllerAnimated:YES completion:nil];
+    }
+    else{
+        [self.loadingAV dismissWithClickedButtonIndex:0 animated:YES];
+    }
+    NSLog(@"dismissLoadingAlert called");
 }
 
 @end
