@@ -17,6 +17,12 @@
 #include <signal.h>
 #include <iostream>
 #include <sstream>
+
+#ifdef _WIN32
+/* Disable deprecation warnings */
+#pragma warning(disable: 4996)
+#endif
+
 #include <alljoyn/notification/NotificationService.h>
 #include <alljoyn/notification/NotificationSender.h>
 #include <alljoyn/notification/NotificationEnums.h>
@@ -77,6 +83,7 @@ void resetParams()
 
 bool createService(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     // Initialize Service object and sent it Notification Receiver object
     if (!testBus) {
         testBus = CommonSampleUtil::prepareBusAttachment();
@@ -203,12 +210,14 @@ bool setCustomAttributes(std::map<qcc::String, qcc::String>& params)
 
 bool setLogger(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     QCC_SetDebugLevel(logModules::NOTIFICATION_MODULE_LOG_NAME, logModules::ALL_LOG_LEVELS);
     return true;
 }
 
 bool initReceive(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     Receiver = new NotificationReceiverTestImpl();
     if (Service->initReceive(testBus, Receiver) != ER_OK) {
         std::cout << "Could not initialize receiver." << std::endl;
@@ -223,6 +232,7 @@ bool initReceive(std::map<qcc::String, qcc::String>& params)
 
 bool ResponseToNotification(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     NotificationReceiverTestImpl::NotificationAction action = ((NotificationReceiverTestImpl::NotificationAction)atoi(params["action"].c_str()));
     Receiver->SetNotificationAction(action);
     return true;
@@ -271,6 +281,7 @@ bool setControlPanelServiceObjectPath(std::map<qcc::String, qcc::String>& params
 
 bool shutdownSender(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     didInitSend = false;
     CommonSampleUtil::aboutServiceDestroy(testBus, notificationBusListener);
 
@@ -281,6 +292,7 @@ bool shutdownSender(std::map<qcc::String, qcc::String>& params)
 
 bool shutdown(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     // clean up
     CommonSampleUtil::aboutServiceDestroy(testBus, notificationBusListener);
     if (notificationBusListener) {
@@ -318,6 +330,7 @@ bool shutdown(std::map<qcc::String, qcc::String>& params)
 
 bool shutdownReceiver(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     didInitReceive = false;
     Service->shutdownReceiver();
     std::cout << "service receiver stopped" << std::endl;
@@ -338,6 +351,7 @@ bool deleteLastMsg(std::map<qcc::String, qcc::String>& params)
 
 bool clearParams(std::map<qcc::String, qcc::String>& params)
 {
+    QCC_UNUSED(params);
     std::cout << "Clearing out message data. " << std::endl;
     resetParams();
     return true;
@@ -560,6 +574,7 @@ void Usage(TestFunction*testFunctions, qcc::String funcName = "", int32_t*functi
 
 void CDECL_CALL signal_callback_handler(int32_t signum)
 {
+    QCC_UNUSED(signum);
     s_interrupt = true;
 }
 
@@ -666,6 +681,7 @@ bool processInput(const qcc::String& input, qcc::String& funcName, std::map<qcc:
 
 int main(int argc, char* argv[])
 {
+    QCC_UNUSED(argv);
     // Initialize AllJoyn
     AJInitializer ajInit;
     if (ajInit.Initialize() != ER_OK) {
