@@ -31,8 +31,8 @@ using namespace services;
 using namespace qcc;
 using namespace nsConsts;
 
-NotificationProducer::NotificationProducer(ajn::BusAttachment* bus, QStatus& status) :
-    BusObject(AJ_NOTIFICATION_PRODUCER_PATH.c_str()), m_InterfaceDescription(NULL), m_BusAttachment(bus)
+NotificationProducer::NotificationProducer(ajn::BusAttachment *bus, QStatus &status, qcc::String pathSuffix) :
+    BusObject((AJ_NOTIFICATION_PRODUCER_PATH + pathSuffix).c_str()), m_InterfaceDescription(NULL), m_BusAttachment(bus)
 {
     m_InterfaceDescription = const_cast<InterfaceDescription*>(m_BusAttachment->GetInterface(AJ_NOTIFICATION_PRODUCER_INTERFACE.c_str()));
     if (!m_InterfaceDescription) {
@@ -54,9 +54,15 @@ NotificationProducer::NotificationProducer(ajn::BusAttachment* bus, QStatus& sta
             return;
         }
 
+        status = m_InterfaceDescription->AddMemberAnnotation(AJ_DISMISS_METHOD_NAME.c_str(), "org.alljoyn.Bus.DocString.En", AJ_DISMISS_METHOD_DESCRIPTION.c_str());
+        if (status != ER_OK) {
+            QCC_LogError(status, ("AddMemberAnnotation failed."));
+            return;
+        }
+
         status = m_InterfaceDescription->AddProperty(AJ_PROPERTY_VERSION.c_str(), AJPARAM_UINT16.c_str(), (uint8_t) PROP_ACCESS_READ);
         if (status != ER_OK) {
-            QCC_LogError(status, ("AddMethod failed."));
+            QCC_LogError(status, ("AddProperty failed."));
             return;
         }
 
