@@ -42,6 +42,12 @@ using namespace services;
 using namespace nsConsts;
 using namespace qcc;
 
+static qcc::String AJ_NOTIFICATION_INTERFACE_MATCH = "type='signal',sessionless='t',interface='"
+                                                    + AJ_NOTIFICATION_INTERFACE_NAME + "'";
+
+static qcc::String AJ_DISMISSER_INTERFACE_MATCH = "type='signal',sessionless='t',interface='"
+                                                 + AJ_NOTIFICATION_DISMISSER_INTERFACE + "'";
+
 Transport* Transport::s_Instance(NULL);
 
 Transport::Transport() : m_Bus(0), m_Receiver(0), m_Consumer(0),
@@ -209,7 +215,6 @@ QStatus Transport::startSenderTransport(BusAttachment* bus)
 
     //Code handles NotificationProducerReceiver - Start
     cleanupNotificationProducerReceiverInternal();
-    cleanupNotificationProducerSenderInternal();
     m_NotificationProducerReceiver = new NotificationProducerReceiver(m_Bus, status);
     if (status != ER_OK) {
         goto exit;
@@ -241,8 +246,7 @@ QStatus Transport::startSenderTransport(BusAttachment* bus)
 
     //Handling NotificationDismisserSender - start here
     cleanupNotificationDismisserSenderInternal();
-    cleanupNotificationDismisserReceiverInternal();
-    m_NotificationDismisserSender = new NotificationDismisserSender(m_Bus, AJ_NOTIFICATION_DISMISSER_PATH, status);
+    m_NotificationDismisserSender = new NotificationDismisserSender(m_Bus, AJ_NOTIFICATION_DISMISSER_PATH + "Sender", status);
     if (status != ER_OK) {
         QCC_LogError(status, ("Could not create NotificationDismisserSender."));
         goto exit;
@@ -276,6 +280,7 @@ QStatus Transport::startReceiverTransport(BusAttachment* bus)
     }
 
     if (m_Consumer == NULL) {
+        cleanupTransportConsumer(true);
         m_Consumer = new NotificationTransportConsumer(m_Bus, AJ_CONSUMER_SERVICE_PATH, status);
         if (status != ER_OK) {
             QCC_LogError(status, ("Could not create Consumer BusObject."));
@@ -288,9 +293,7 @@ QStatus Transport::startReceiverTransport(BusAttachment* bus)
             goto exit;
         }
 
-        String AJ_NOTIFICATION_INTERFACE_MATCH = "type='signal',sessionless='t',interface='" + AJ_NOTIFICATION_INTERFACE_NAME + "'";
         QCC_DbgPrintf(("Match String is: %s", AJ_NOTIFICATION_INTERFACE_MATCH.c_str()));
-
         status = m_Bus->AddMatch(AJ_NOTIFICATION_INTERFACE_MATCH.c_str());
 
         if (status != ER_OK) {
@@ -301,7 +304,6 @@ QStatus Transport::startReceiverTransport(BusAttachment* bus)
 
     //Handling NotificationProducerSender - Start
     if (m_NotificationProducerSender == NULL) {
-        cleanupNotificationProducerReceiverInternal();
         m_NotificationProducerSender = new NotificationProducerSender(m_Bus, status);
         if (status != ER_OK) {
             QCC_LogError(status, ("Could not create NotificationProducerSender BusObject."));
@@ -317,7 +319,7 @@ QStatus Transport::startReceiverTransport(BusAttachment* bus)
 
     //Handling NotificationDismisserReceiver - Start
     if (m_NotificationDismisserReceiver == NULL) {
-        cleanupNotificationDismisserSenderInternal();
+        cleanupNotificationDismisserReceiverInternal();
         m_NotificationDismisserReceiver = new NotificationDismisserReceiver(m_Bus, status);
         if (status != ER_OK) {
             QCC_LogError(status, ("Could not create NotificationDismisserReceiver BusObject."));
@@ -329,7 +331,6 @@ QStatus Transport::startReceiverTransport(BusAttachment* bus)
             goto exit;
         }
 
-        String AJ_DISMISSER_INTERFACE_MATCH = "type='signal',sessionless='t',interface='" + AJ_NOTIFICATION_DISMISSER_INTERFACE + "'";
         QCC_DbgPrintf(("NotificationDismisserReceiver Match String is: %s", AJ_DISMISSER_INTERFACE_MATCH.c_str()));
 
         status = m_Bus->AddMatch(AJ_DISMISSER_INTERFACE_MATCH.c_str());
@@ -342,8 +343,8 @@ QStatus Transport::startReceiverTransport(BusAttachment* bus)
 
     //Handling NotificationDismisserSender - Start
     if (m_NotificationDismisserSender == NULL) {
-        cleanupNotificationDismisserReceiverInternal();
-        m_NotificationDismisserSender = new NotificationDismisserSender(m_Bus, AJ_NOTIFICATION_DISMISSER_PATH, status);
+        cleanupNotificationDismisserSenderInternal();
+        m_NotificationDismisserSender = new NotificationDismisserSender(m_Bus, AJ_NOTIFICATION_DISMISSER_PATH + "Sender", status);
         if (status != ER_OK) {
             QCC_LogError(status, ("Could not create NotificationDismisserSender."));
             goto exit;
@@ -437,7 +438,8 @@ void Transport::cleanupNotificationDismisserSenderInternal()
     if (!m_NotificationDismisserSender) {
         return;
     }
-
+    
+    m_Bus->RemoveMatch(AJ_DISMISSER_INTERFACE_MATCH.c_str());
     m_Bus->UnregisterBusObject(*m_NotificationDismisserSender);
 }
 
@@ -488,6 +490,8 @@ void Transport::cleanupTransportConsumer(bool unregister)
     if (!m_Consumer) {
         return;
     }
+    
+    m_Bus->RemoveMatch(AJ_NOTIFICATION_INTERFACE_MATCH.c_str());
 
     if (unregister) {
         m_Consumer->unregisterHandler(m_Bus);
