@@ -53,6 +53,7 @@ import android.widget.CheckBox;
 import android.widget.EditText;
 import android.widget.ListView;
 import android.widget.Spinner;
+import android.widget.Toast;
 
 /**
  * Test the onboardingSDK functionality.
@@ -78,7 +79,8 @@ public class MainActivity extends Activity {
     /**
      * Listen to the two main OnboardingManager Intents. Log intents with the
      * action "OnboardingManager.STATE_CHANGE_ACTION" in a list Display alert
-     * dialog for intents with the action "OnboardingManager.ERROR".
+     * dialog for intents with the action "OnboardingManager.ERROR". Additionally, listen
+     * for intent that marshmallow network code is running and that some features will be unavailable.
      */
     private final BroadcastReceiver mainReceiver = new BroadcastReceiver() {
         @Override
@@ -108,6 +110,11 @@ public class MainActivity extends Activity {
 
                 showErrorMessage(getString(R.string.error), intentString);
             }
+            else if (intent.getAction().equals(OnboardingManager.MARSHMALLOW_SOFTAP_CONNECT)){
+                Log.d(TAG, "Display marshmallow softAP connect toast");
+                Toast toast = Toast.makeText(getApplicationContext(), "Android Marshmallow will not update network settings.", Toast.LENGTH_LONG);
+                toast.show();
+            }
         }
     };
 
@@ -226,11 +233,11 @@ public class MainActivity extends Activity {
         logListAdapter = new ArrayAdapter<String>(MainActivity.this, android.R.layout.simple_list_item_1);
 
         // Creates new IntentFilter and add two main OnboardingManager Actions
-        // to
-        // it.
+        // to it. Also include detection for marshmallow specific flow.
         mainFilter = new IntentFilter();
         mainFilter.addAction(OnboardingManager.STATE_CHANGE_ACTION);
         mainFilter.addAction(OnboardingManager.ERROR);
+        mainFilter.addAction(OnboardingManager.MARSHMALLOW_SOFTAP_CONNECT);
     }
 
     @Override
@@ -319,6 +326,7 @@ public class MainActivity extends Activity {
         View networkCredentialsLayout = inflater.inflate(R.layout.connect_to_network_layout, null);
         final EditText ssidEditText = (EditText) networkCredentialsLayout.findViewById(R.id.network_credentials_ssid_editText);
         final EditText passwordEditText = (EditText) networkCredentialsLayout.findViewById(R.id.network_credentials_password_editText);
+        final CheckBox networkHidden = (CheckBox) networkCredentialsLayout.findViewById(R.id.network_hidden);
         final Spinner authTypeSpinner = (Spinner) networkCredentialsLayout.findViewById(R.id.network_credentials_layout_authType_spinner);
         final EditText timeoutEditText = (EditText) networkCredentialsLayout.findViewById(R.id.network_credentials_timeout_editText);
         timeoutEditText.setText(String.valueOf(OnboardingManager.DEFAULT_WIFI_CONNECTION_TIMEOUT));
@@ -343,7 +351,7 @@ public class MainActivity extends Activity {
                 AuthType authType = AuthType.valueOf((String) authTypeSpinner.getSelectedItem());
                 int timeout = Integer.valueOf(timeoutEditText.getText().toString());
 
-                WiFiNetworkConfiguration wifi = new WiFiNetworkConfiguration(ssid, authType, password);
+                WiFiNetworkConfiguration wifi = new WiFiNetworkConfiguration(ssid, authType, password, networkHidden.isChecked());
                 try {
                     OnboardingManager.getInstance().connectToNetwork(wifi, timeout);
                 } catch (WifiDisabledException e) {
