@@ -17,7 +17,9 @@ package org.alljoyn.ioe.onboardingtest;
 import java.io.BufferedInputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.lang.Override;
 import java.util.Map;
+import java.io.ByteArrayOutputStream;
 
 import org.alljoyn.about.AboutServiceImpl;
 import org.alljoyn.bus.BusAttachment;
@@ -42,16 +44,20 @@ import org.alljoyn.services.android.storage.PropertyStoreImpl;
 import org.alljoyn.services.android.utils.AndroidLogger;
 import org.alljoyn.services.common.PropertyStore;
 import org.alljoyn.services.common.utils.GenericLogger;
-import org.apache.http.util.ByteArrayBuffer;
 
 import android.app.Service;
+import android.content.Context;
 import android.content.Intent;
+import android.content.IntentFilter;
+import android.content.BroadcastReceiver;
+import android.os.Bundle;
 import android.os.Handler;
 import android.os.HandlerThread;
 import android.os.IBinder;
 import android.os.Looper;
 import android.os.Message;
 import android.util.Log;
+import android.widget.Toast;
 
 /**
  * The OnboardingServer is a board simulator written for Android.
@@ -78,7 +84,10 @@ public class OnboardingServer extends Service implements AuthPasswordHandler, Se
 
     // the password for secured sessions
     private char[] m_myPass;
-    
+
+    // receive broadcasts indicating network state
+    private BroadcastReceiver m_broadcastReceiver;
+
     //Supported Authentication mechanisms
     private static final String[] AUTH_MECHANISMS = new String[]{"ALLJOYN_SRP_KEYX", "ALLJOYN_ECDHE_PSK"};
     
@@ -119,6 +128,29 @@ public class OnboardingServer extends Service implements AuthPasswordHandler, Se
 
         // initialize the state machine
         m_asyncHandler.sendEmptyMessage(AsyncHandler.CONNECT);
+
+        m_broadcastReceiver = new BroadcastReceiver() {
+            @Override
+            public void onReceive(Context context, Intent intent) {
+                String action = intent.getAction();
+                Bundle extras = intent.getExtras();
+                if (action.equals(OnboardingServiceImpl.ENABLE_WIFI_FAILED)) {
+                    showToast(extras.getString(OnboardingServiceImpl.CONNECTION_FAILURE_REASON), Toast.LENGTH_LONG);
+                }
+                else if (action.equals(OnboardingServiceImpl.STOP_SOFTAP_FAILED)) {
+                    showToast(extras.getString(OnboardingServiceImpl.CONNECTION_FAILURE_REASON), Toast.LENGTH_LONG);
+                }
+                else if (action.equals(OnboardingServiceImpl.WIFI_CONFIG_FAILED)) {
+                    showToast(extras.getString(OnboardingServiceImpl.WIFI_CONFIG_FAILURE_REASON), Toast.LENGTH_LONG);
+                }
+            }
+        };
+
+        IntentFilter filter = new IntentFilter();
+        filter.addAction(OnboardingServiceImpl.ENABLE_WIFI_FAILED);
+        filter.addAction(OnboardingServiceImpl.STOP_SOFTAP_FAILED);
+        filter.addAction(OnboardingServiceImpl.WIFI_CONFIG_FAILED);
+        registerReceiver(m_broadcastReceiver, filter);
     }
 
     /* (non-Javadoc)
@@ -143,6 +175,8 @@ public class OnboardingServer extends Service implements AuthPasswordHandler, Se
         m_asyncHandler.shutdown();
         m_asyncHandler.getLooper().quit();
 
+        unregisterReceiver(m_broadcastReceiver);
+
         super.onDestroy();
 
     }
@@ -205,9 +239,9 @@ public class OnboardingServer extends Service implements AuthPasswordHandler, Se
 
             // Pump up the daemon debug level
             /*
-			m_Bus.setDaemonDebug("ALL", 7);
-			m_Bus.setLogLevels("ALL=7");
-			m_Bus.useOSLogging(true);
+            m_Bus.setDaemonDebug("ALL", 7);
+            m_Bus.setLogLevels("ALL=7");
+            m_Bus.useOSLogging(true);
              */
 
             // initialize the PropertyStore
@@ -247,17 +281,17 @@ public class OnboardingServer extends Service implements AuthPasswordHandler, Se
                 int bufferSize = 1024*10;
                 byte[] buffer = new byte[bufferSize];
 
-                ByteArrayBuffer tempArray = new ByteArrayBuffer(bufferSize);
+                ByteArrayOutputStream tempArray = new ByteArrayOutputStream(bufferSize);
                 try {
                     while ((count = bis.read(buffer, offset, bufferSize)) != -1) {
-                        tempArray.append(buffer, offset, count);
+                        tempArray.write(buffer, offset, count);
                     }
                 } catch (IOException e) {
                     e.printStackTrace();
                 }
-                int size = tempArray.length();
+                int size = tempArray.size();
                 byte[] resultBytes = new byte[size];
-                System.arraycopy(tempArray.buffer(), 0, resultBytes, 0, size);
+                System.arraycopy(tempArray.toByteArray(), 0, resultBytes, 0, size);
 
                 // register the byte array as the board's icon. The AboutService will expose it
                 AboutServiceImpl.getInstance().registerIcon("image/png",
@@ -410,7 +444,13 @@ public class OnboardingServer extends Service implements AuthPasswordHandler, Se
     public void showToast(String text)
     {
         System.out.println(text);
-        //		Toast.makeText(this, text, Toast.LENGTH_SHORT).show();
+        Toast.makeText(this, text, Toast.LENGTH_SHORT).show();
+    }
+
+    public void showToast(String text, int length)
+    {
+        System.out.println(text);
+        Toast.makeText(this, text, length).show();
     }
 
     private String bindSessionPort(final short port)
